@@ -1,5 +1,7 @@
 """
-Main interface for cloudhsm service literal definitions.
+Type annotations for cloudhsm service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/literals.html)
 
 Usage::
 
